#!/usr/bin/env python
import builtins
import inspect
try:
    import io  # Python3
except Exception:
    pass

import re
from objectname import objectname
from isstring import isstring
from public import public


def isregex(obj):
    _pattern_type = getattr(re, "_pattern_type")
    return isinstance(obj, _pattern_type)


def isfilehandler(obj):
    try:
        return isinstance(obj, builtins.file)  # python2
    except Exception:
        return isinstance(obj, io.IOBase)  # python3


@public
def formatvalue(value):
    if value is None:
        return "=None"
    if isstring(value):
        return "='%s'" % value.replace("\n", "").replace("/", ":")
    if inspect.isclass(value):
        if inspect.getmodule(value) != builtins:
            return "=%s" % objectname(value, fullname=True)
        else:
            return "=%s" % value.__name__
    if isfilehandler(value):
        value = value.name
    if isregex(value):
        value = 'r"%s"' % value.pattern
    if "instance at" in str(value) or "object at" in str(value):
        cls = objectname(value.__class__, fullname=True)
        cls = cls.replace("__builtin__.", "")
        value = "<%s instance>" % cls
    if inspect.isfunction(value):
        if inspect.isbuiltin(value):
            return "=%s" % value.__name__
        else:
            return "=%s" % objectname(value, fullname=True)
    return "=%s" % str(value)
